@@ -7,19 +7,19 @@
 #'
 #' @param dataset Input dataset
 #'
-#'   The variables specified for `subject_keys` and the `PARAMCD` variable are
+#'   The variables specified for `by_vars` and the `PARAMCD` variable are
 #'   expected.
 #'
-#' @param dataset_adsl ADSL input dataset
+#' @param dataset_ref Reference dataset, e.g., ADSL
 #'
-#'   The variables specified for `subject_keys` are expected. For each subject
-#'   (as defined by `subject_keys`) from the specified dataset (`dataset_adsl`),
+#'   The variables specified in `by_vars` are expected. For each group
+#'   (as defined by `by_vars`) from the specified dataset (`dataset_ref`),
 #'   the existence flag is calculated and added as a new observation to the
-#'   input datasets (`dataset`)
+#'   input datasets (`dataset`).
 #'
 #' @param dataset_add Additional dataset
 #'
-#'   The variables specified by the `subject_keys` parameter are expected.
+#'   The variables specified by the `by_vars` parameter are expected.
 #'
 #'   This dataset is used to check if an event occurred or not. Any observation
 #'   in the dataset fulfilling the event condition (`condition`) is considered
@@ -29,18 +29,18 @@
 #'
 #'   The condition is evaluated at the additional dataset (`dataset_add`).
 #'
-#'   For all subjects where it evaluates as `TRUE` at least once `AVALC` is set
+#'   For all groups where it evaluates as `TRUE` at least once `AVALC` is set
 #'   to the true value (`true_value`) for the new observations.
 #'
-#'   For all subjects where it evaluates as `FALSE` or `NA` for all observations
+#'   For all groups where it evaluates as `FALSE` or `NA` for all observations
 #'   `AVALC` is set to the false value (`false_value`).
 #'
-#'   For all subjects not present in the additional dataset `AVALC` is set to
+#'   For all groups not present in the additional dataset `AVALC` is set to
 #'   the missing value (`missing_value`).
 #'
 #' @param true_value True value
 #'
-#'   For all subjects with at least one observations in the additional dataset
+#'   For all groups with at least one observations in the additional dataset
 #'   (`dataset_add`) fulfilling the event condition (`condition`), `AVALC` is
 #'   set to the specified value (`true_value`).
 #'
@@ -50,7 +50,7 @@
 #'
 #' @param false_value False value
 #'
-#'   For all subjects with at least one observations in the additional dataset
+#'   For all groups with at least one observations in the additional dataset
 #'   (`dataset_add`) but none of them is fulfilling the event condition
 #'   (`condition`), `AVALC` is set to the specified value (`false_value`).
 #'
@@ -60,7 +60,7 @@
 #'
 #' @param missing_value Values used for missing information
 #'
-#'   For all subjects without an observation in the additional dataset
+#'   For all groups without an observation in the additional dataset
 #'   (`dataset_add`), `AVALC` is set to the specified value (`missing_value`).
 #'
 #'   *Default*: `NA_character_`
@@ -78,40 +78,39 @@
 #' @param aval_fun Function to map character analysis value (`AVALC`) to numeric
 #'   analysis value (`AVAL`)
 #'
-#'   The (first) argument of the function must expect a character vector and the
-#'   function must return a numeric vector.
-#'
-#'   *Default:* `yn_to_numeric` (see `yn_to_numeric()` for details)
+#'   *Deprecated*, please use `set_values_to` instead.
 #'
 #' @param set_values_to Variables to set
 #'
 #'   A named list returned by `exprs()` defining the variables to be set for the
 #'   new parameter, e.g. `exprs(PARAMCD = "MDIS", PARAM = "Measurable Disease at
 #'   Baseline")` is expected. The values must be symbols, character strings,
-#'   numeric values, or `NA`.
+#'   numeric values, `NA`, or expressions.
 #'
-#' @param subject_keys Variables to uniquely identify a subject
+#' @param by_vars Variables to uniquely identify a group
 #'
 #'   A list of symbols created using `exprs()` is expected.
 #'
+#' @param dataset_adsl *Deprecated*, please use `dataset_ref` instead.
+#'
+#' @param subject_keys *Deprecated*, please use `by_vars` instead.
+#'
 #' @details
 #'   1. The additional dataset (`dataset_add`) is restricted to the observations
 #'   matching the `filter_add` condition.
 #'
-#'   1. For each subject in `dataset_adsl` a new observation is created.
+#'   1. For each group in `dataset_ref` a new observation is created.
 #'
 #'       - The `AVALC` variable is added and set to the true value (`true_value`)
-#'         if for the subject at least one observation exists in the (restricted)
+#'         if for the group at least one observation exists in the (restricted)
 #'         additional dataset where the condition evaluates to `TRUE`.
 #'
-#'       - It is set to the false value (`false_value`) if for the subject at least
+#'       - It is set to the false value (`false_value`) if for the group at least
 #'         one observation exists and for all observations the condition evaluates
 #'         to `FALSE` or `NA`.
 #'
 #'       - Otherwise, it is set to the missing value (`missing_value`), i.e., for
-#'         those subject not in `dataset_add`.
-#'
-#'   1. The `AVAL` variable is added and set to `aval_fun(AVALC)`.
+#'         those groups not in `dataset_add`.
 #'
 #'   1. The variables specified by the `set_values_to` parameter are added to
 #'   the new observations.
@@ -120,8 +119,8 @@
 #'
 #'
 #' @return The input dataset with a new parameter indicating if an event
-#'   occurred (`AVALC`, `AVAL`, and the variables specified by `subject_keys`
-#'   and `set_value_to` are populated for the new parameter)
+#'   occurred (`AVALC` and the variables specified by `by_vars`
+#'   and `set_value_to` are populated for the new parameter).
 #'
 #' @family der_prm_bds_findings
 #'
@@ -158,70 +157,97 @@
 #'   )
 #'
 #' derive_param_exist_flag(
-#'   dataset_adsl = adsl,
+#'   dataset_ref = adsl,
 #'   dataset_add = tu,
 #'   filter_add = TUTESTCD == "TUMIDENT" & VISIT == "SCREENING",
 #'   condition = TUSTRESC == "TARGET",
 #'   false_value = "N",
 #'   missing_value = "N",
 #'   set_values_to = exprs(
+#'     AVAL = yn_to_numeric(AVALC),
 #'     PARAMCD = "MDIS",
 #'     PARAM = "Measurable Disease at Baseline"
 #'   )
 #' )
 derive_param_exist_flag <- function(dataset = NULL,
-                                    dataset_adsl,
+                                    dataset_ref,
                                     dataset_add,
                                     condition,
                                     true_value = "Y",
                                     false_value = NA_character_,
                                     missing_value = NA_character_,
                                     filter_add = NULL,
-                                    aval_fun = yn_to_numeric,
-                                    subject_keys = get_admiral_option("subject_keys"),
-                                    set_values_to) {
+                                    aval_fun,
+                                    by_vars = get_admiral_option("subject_keys"),
+                                    set_values_to,
+                                    dataset_adsl,
+                                    subject_keys) {
+  ### BEGIN DEPRECATION
+  if (!missing(dataset_adsl)) {
+    deprecate_warn(
+      "0.11.0", "derive_param_exist_flag(dataset_adsl = )",
+      "derive_param_exit_flag(dataset_ref = )"
+    )
+    # assign deprecated argument to new variable
+    dataset_ref <- dataset_adsl
+  }
+
+  if (!missing(subject_keys)) {
+    deprecate_warn(
+      "0.11.0", "derive_param_exist_flag(subject_keys = )",
+      "derive_param_exit_flag(by_vars = )"
+    )
+    # assign deprecated argument to new variable
+    by_vars <- subject_keys
+  }
+  ### END DEPRECATION
+
   # Check input parameters
   condition <- assert_filter_cond(enexpr(condition))
   assert_character_scalar(true_value)
   assert_character_scalar(false_value)
   assert_character_scalar(missing_value)
   filter_add <- assert_filter_cond(enexpr(filter_add), optional = TRUE)
-  assert_function(aval_fun)
-  assert_vars(subject_keys)
+  assert_vars(by_vars)
   assert_data_frame(
     dataset,
-    required_vars = exprs(PARAMCD, !!!subject_keys),
+    required_vars = exprs(PARAMCD, !!!by_vars),
     optional = TRUE
   )
-  assert_data_frame(dataset_adsl, required_vars = subject_keys)
-  assert_data_frame(dataset_add, required_vars = subject_keys)
+  assert_data_frame(dataset_ref, required_vars = by_vars)
+  assert_data_frame(dataset_add, required_vars = by_vars)
   assert_varval_list(set_values_to, required_elements = "PARAMCD")
   if (!is.null(dataset)) {
     assert_param_does_not_exist(dataset, set_values_to$PARAMCD)
   }
 
+  if (!missing(aval_fun)) {
+    assert_function(aval_fun)
+    deprecate_warn(
+      "0.11.0",
+      "derive_param_exist_flag(aval_fun = )",
+      "derive_param_exist_flag(set_values_to = )"
+    )
+    set_values_to <- exprs(!!!set_values_to, AVAL = aval_fun(AVALC))
+  }
+
   # Create new observations
   new_obs <- derive_var_merged_exist_flag(
-    dataset_adsl,
+    dataset_ref,
     dataset_add = dataset_add,
     filter_add = !!filter_add,
     condition = !!condition,
-    by_vars = subject_keys,
+    by_vars = by_vars,
     new_var = AVALC,
     true_value = true_value,
     false_value = false_value,
     missing_value = missing_value
   )
-  new_obs <- call_user_fun(mutate(new_obs, AVAL = aval_fun(AVALC)))
 
-  if (!is.numeric(new_obs$AVAL)) {
-    abort(paste(
-      "Calling `aval_fun(AVALC)` did not result in a numeric vector.\n",
-      "A", typeof(new_obs$AVAL), "vector was returned."
-    ))
-  }
-
-  new_obs <- mutate(new_obs, !!!set_values_to)
+  new_obs <- process_set_values_to(
+    new_obs,
+    set_values_to = set_values_to
+  )
 
   # Create output dataset
   bind_rows(dataset, new_obs)
