@@ -10,27 +10,27 @@
 #'   [Queries Dataset Documentation vignette](../articles/queries_dataset.html)
 #'   for descriptions, or call `data("queries")` for an example of a query dataset.
 #'
-#'   For each unique element in `VAR_PREFIX`, the corresponding "NAM"
-#'   variable will be created. For each unique `VAR_PREFIX`, if `QUERY_ID` is
+#'   For each unique element in `PREFIX`, the corresponding "NAM"
+#'   variable will be created. For each unique `PREFIX`, if `GRPID` is
 #'   not "" or NA, then the corresponding "CD" variable is created; similarly,
-#'   if `QUERY_SCOPE` is not "" or NA, then the corresponding "SC" variable will
-#'   be created; if `QUERY_SCOPE_NUM` is not "" or NA, then the corresponding
+#'   if `SCOPE` is not "" or NA, then the corresponding "SC" variable will
+#'   be created; if `SCOPEN` is not "" or NA, then the corresponding
 #'   "SCN" variable will be created.
 #'
 #'   For each record in `dataset`, the "NAM" variable takes the value of
-#'   `QUERY_NAME` if the value of `TERM_NAME` or `TERM_ID` in `dataset_queries` matches
-#'   the value of the respective TERM_LEVEL in `dataset`.
-#'   Note that `TERM_NAME` in `dataset_queries` dataset may be NA only when `TERM_ID`
+#'   `GRPNAME` if the value of `TERMNAME` or `TERMID` in `dataset_queries` matches
+#'   the value of the respective SRCVAR in `dataset`.
+#'   Note that `TERMNAME` in `dataset_queries` dataset may be NA only when `TERMID`
 #'   is non-NA and vice versa.
 #'   The "CD", "SC", and "SCN" variables are derived accordingly based on
-#'   `QUERY_ID`, `QUERY_SCOPE`, and `QUERY_SCOPE_NUM` respectively,
+#'   `GRPID`, `SCOPE`, and `SCOPEN` respectively,
 #'   whenever not missing.
 #'
 #' @param dataset Input dataset.
 #'
-#' @param dataset_queries A dataset containing required columns `VAR_PREFIX`,
-#' `QUERY_NAME`, `TERM_LEVEL`, `TERM_NAME`, `TERM_ID`, and optional columns
-#' `QUERY_ID`, `QUERY_SCOPE`, `QUERY_SCOPE_NUM`.
+#' @param dataset_queries A dataset containing required columns `PREFIX`,
+#' `GRPNAME`, `SRCVAR`, `TERMNAME`, `TERMID`, and optional columns
+#' `GRPID`, `SCOPE`, `SCOPEN`.
 #'
 #'   The content of the dataset will be verified by [assert_valid_queries()].
 #'
@@ -65,34 +65,34 @@ derive_vars_query <- function(dataset, dataset_queries) {
   assert_data_frame(dataset_queries)
   assert_valid_queries(dataset_queries, queries_name = deparse(substitute(dataset_queries)))
   assert_data_frame(dataset,
-    required_vars = exprs(!!!syms(unique(dataset_queries$TERM_LEVEL))),
+    required_vars = exprs(!!!syms(unique(dataset_queries$SRCVAR))),
     optional = FALSE
   )
 
   dataset_queries <- convert_blanks_to_na(dataset_queries)
 
   # names of new columns
-  if ("QUERY_ID" %notin% names(dataset_queries)) {
-    dataset_queries$QUERY_ID <- NA_integer_ # nolint
+  if ("GRPID" %notin% names(dataset_queries)) {
+    dataset_queries$GRPID <- NA_integer_ # nolint
   }
-  if ("QUERY_SCOPE" %notin% names(dataset_queries)) {
-    dataset_queries$QUERY_SCOPE <- NA_integer_ # nolint
+  if ("SCOPE" %notin% names(dataset_queries)) {
+    dataset_queries$SCOPE <- NA_integer_ # nolint
   }
-  if ("QUERY_SCOPE_NUM" %notin% names(dataset_queries)) {
-    dataset_queries$QUERY_SCOPE_NUM <- NA_integer_ # nolint
+  if ("SCOPEN" %notin% names(dataset_queries)) {
+    dataset_queries$SCOPEN <- NA_integer_ # nolint
   }
   new_col_names <- dataset_queries %>%
-    group_by(VAR_PREFIX) %>%
+    group_by(PREFIX) %>%
     mutate(
-      NAM = paste0(VAR_PREFIX, "NAM"),
-      CD = ifelse(!all(is.na(QUERY_ID)),
-        paste0(VAR_PREFIX, "CD"), NA_character_
+      NAM = paste0(PREFIX, "NAM"),
+      CD = ifelse(!all(is.na(GRPID)),
+        paste0(PREFIX, "CD"), NA_character_
       ),
-      SC = ifelse(!all(is.na(QUERY_SCOPE)),
-        paste0(VAR_PREFIX, "SC"), NA_character_
+      SC = ifelse(!all(is.na(SCOPE)),
+        paste0(PREFIX, "SC"), NA_character_
       ),
-      SCN = ifelse(!all(is.na(QUERY_SCOPE_NUM)),
-        paste0(VAR_PREFIX, "SCN"), NA_character_
+      SCN = ifelse(!all(is.na(SCOPEN)),
+        paste0(PREFIX, "SCN"), NA_character_
       )
     ) %>%
     ungroup() %>%
@@ -101,8 +101,8 @@ derive_vars_query <- function(dataset, dataset_queries) {
     pivot_longer(c(NAM, CD, SC, SCN), names_to = "key", values_to = "value") %>%
     filter(!is.na(value)) %>%
     mutate(
-      order1 = stringr::str_extract(value, "^[a-zA-Z]{2,3}"),
-      order2 = stringr::str_extract(value, "\\d{2}"),
+      order1 = str_extract(value, "^[a-zA-Z]{2,3}"),
+      order2 = str_extract(value, "\\d{2}"),
       order3 = as.integer(factor(key, levels = c("NAM", "CD", "SC", "SCN")))
     ) %>%
     arrange(desc(order1), order2, order3) %>%
@@ -111,24 +111,24 @@ derive_vars_query <- function(dataset, dataset_queries) {
   # queries restructured
   queries_wide <- dataset_queries %>%
     mutate(
-      TERM_NAME = toupper(.data$TERM_NAME),
-      VAR_PREFIX_NAM = paste0(.data$VAR_PREFIX, "NAM")
+      TERMNAME = toupper(TERMNAME),
+      PREFIX_NAM = paste0(PREFIX, "NAM")
     ) %>%
-    pivot_wider(names_from = .data$VAR_PREFIX_NAM, values_from = .data$QUERY_NAME) %>%
-    mutate(VAR_PREFIX_CD = paste0(.data$VAR_PREFIX, "CD")) %>%
-    pivot_wider(names_from = .data$VAR_PREFIX_CD, values_from = .data$QUERY_ID) %>%
-    mutate(VAR_PREFIX_SC = paste0(.data$VAR_PREFIX, "SC")) %>%
-    pivot_wider(names_from = .data$VAR_PREFIX_SC, values_from = .data$QUERY_SCOPE) %>%
-    mutate(VAR_PREFIX_SCN = paste0(.data$VAR_PREFIX, "SCN")) %>%
-    pivot_wider(names_from = .data$VAR_PREFIX_SCN, values_from = .data$QUERY_SCOPE_NUM) %>%
-    select(-VAR_PREFIX) %>%
-    # determine join column based on type of TERM_LEVEL
-    # numeric -> TERM_ID, character -> TERM_NAME, otherwise -> error
+    pivot_wider(names_from = PREFIX_NAM, values_from = GRPNAME) %>%
+    mutate(PREFIX_CD = paste0(PREFIX, "CD")) %>%
+    pivot_wider(names_from = PREFIX_CD, values_from = GRPID) %>%
+    mutate(PREFIX_SC = paste0(PREFIX, "SC")) %>%
+    pivot_wider(names_from = PREFIX_SC, values_from = SCOPE) %>%
+    mutate(PREFIX_SCN = paste0(PREFIX, "SCN")) %>%
+    pivot_wider(names_from = PREFIX_SCN, values_from = SCOPEN) %>%
+    select(-PREFIX) %>%
+    # determine join column based on type of SRCVAR
+    # numeric -> TERMID, character -> TERMNAME, otherwise -> error
     mutate(
-      tmp_col_type = vapply(dataset[.data$TERM_LEVEL], typeof, character(1)),
+      tmp_col_type = vapply(dataset[SRCVAR], typeof, character(1)),
       TERM_NAME_ID = case_when(
-        .data$tmp_col_type == "character" ~ .data$TERM_NAME,
-        .data$tmp_col_type %in% c("double", "integer") ~ as.character(.data$TERM_ID),
+        tmp_col_type == "character" ~ TERMNAME,
+        tmp_col_type %in% c("double", "integer") ~ as.character(TERMID),
         TRUE ~ NA_character_
       )
     )
@@ -136,7 +136,7 @@ derive_vars_query <- function(dataset, dataset_queries) {
   # throw error if any type of column is not character or numeric
   if (any(is.na(queries_wide$TERM_NAME_ID))) {
     idx <- is.na(queries_wide$TERM_NAME_ID)
-    dat_incorrect_type <- dataset[queries_wide$TERM_LEVEL[idx]]
+    dat_incorrect_type <- dataset[queries_wide$SRCVAR[idx]]
     msg <- paste0(
       paste0(
         colnames(dat_incorrect_type),
@@ -150,10 +150,10 @@ derive_vars_query <- function(dataset, dataset_queries) {
   }
 
   # prepare input dataset for joining
-  static_cols <- setdiff(names(dataset), unique(dataset_queries$TERM_LEVEL))
+  static_cols <- setdiff(names(dataset), unique(dataset_queries$SRCVAR))
   # if dataset does not have a unique key, create a temp one
   no_key <- dataset %>%
-    select(!!!syms(static_cols)) %>%
+    select(all_of(static_cols)) %>%
     distinct()
   if (nrow(no_key) != nrow(dataset)) {
     dataset$temp_key <- seq_len(nrow(dataset))
@@ -161,25 +161,25 @@ derive_vars_query <- function(dataset, dataset_queries) {
   }
 
   # Keep static variables - will add back on once non-static vars fixed
-  df_static <- dataset %>% select(static_cols)
+  df_static <- dataset %>% select(all_of(static_cols))
 
   # Change non-static numeric vars to character
   df_fix_numeric <- dataset %>%
-    select(-static_cols) %>%
+    select(-all_of(static_cols)) %>%
     mutate(across(where(is.numeric), as.character))
 
 
   joined <- cbind(df_static, df_fix_numeric) %>%
-    pivot_longer(-static_cols, names_to = "TERM_LEVEL", values_to = "TERM_NAME_ID") %>%
-    drop_na(.data$TERM_NAME_ID) %>%
-    mutate(TERM_NAME_ID = toupper(.data$TERM_NAME_ID))
+    pivot_longer(-all_of(static_cols), names_to = "SRCVAR", values_to = "TERM_NAME_ID") %>%
+    drop_na(TERM_NAME_ID) %>%
+    mutate(TERM_NAME_ID = toupper(TERM_NAME_ID))
 
   # join restructured queries to input dataset
   joined <- joined %>%
-    inner_join(queries_wide, by = c("TERM_LEVEL", "TERM_NAME_ID")) %>%
+    inner_join(queries_wide, by = c("SRCVAR", "TERM_NAME_ID")) %>%
     select(!!!syms(c(static_cols, new_col_names))) %>%
-    dplyr::group_by_at(static_cols) %>%
-    dplyr::summarise_all(~ dplyr::first(na.omit(.))) %>%
+    group_by_at(static_cols) %>%
+    summarise_all(~ first(na.omit(.))) %>%
     ungroup()
 
   # join queries to input dataset
@@ -190,16 +190,16 @@ derive_vars_query <- function(dataset, dataset_queries) {
 #' Verify if a Dataset Has the Required Format as Queries Dataset.
 #'
 #' @details Check if the dataset has the following columns
-#' - `VAR_PREFIX`, e.g., SMQ01, CQ12
-#' - `QUERY_NAME`, non NA, must be unique per each `VAR_PREFIX`
-#' - `QUERY_ID`, could be NA, must be unique per each `VAR_PREFIX`
-#' - `QUERY_SCOPE`, 'BROAD', 'NARROW', or NA
-#' - `QUERY_SCOPE_NUM`, 1, 2, or NA
-#' - `TERM_LEVEL`, e.g., `"AEDECOD"`, `"AELLT"`, `"AELLTCD"`, ...
-#' - `TERM_NAME`, character, could be NA only at those observations
-#' where `TERM_ID` is non-NA
-#' - `TERM_ID`, integer, could be NA only at those observations
-#' where `TERM_NAME` is non-NA
+#' - `PREFIX`, e.g., SMQ01, CQ12
+#' - `GRPNAME`, non NA, must be unique per each `PREFIX`
+#' - `GRPID`, could be NA, must be unique per each `PREFIX`
+#' - `SCOPE`, 'BROAD', 'NARROW', or NA
+#' - `SCOPEN`, 1, 2, or NA
+#' - `SRCVAR`, e.g., `"AEDECOD"`, `"AELLT"`, `"AELLTCD"`, ...
+#' - `TERMNAME`, character, could be NA only at those observations
+#' where `TERMID` is non-NA
+#' - `TERMID`, integer, could be NA only at those observations
+#' where `TERMNAME` is non-NA
 #'
 #' @param queries A data.frame.
 #'
@@ -220,73 +220,73 @@ assert_valid_queries <- function(queries, queries_name) {
   # check required columns
   assert_has_variables(
     queries,
-    c("VAR_PREFIX", "QUERY_NAME", "TERM_LEVEL", "TERM_NAME", "TERM_ID")
+    c("PREFIX", "GRPNAME", "SRCVAR", "TERMNAME", "TERMID")
   )
 
   # check duplicate rows
   signal_duplicate_records(queries, by_vars = exprs(!!!syms(colnames(queries))))
 
   # check illegal prefix category
-  is_good_prefix <- grepl("^[a-zA-Z]{2,3}", queries$VAR_PREFIX)
+  is_good_prefix <- grepl("^[a-zA-Z]{2,3}", queries$PREFIX)
   if (!all(is_good_prefix)) {
     abort(
       paste0(
-        "`VAR_PREFIX` in `", queries_name,
+        "`PREFIX` in `", queries_name,
         "` must start with 2-3 letters.. Problem with ",
-        enumerate(unique(queries$VAR_PREFIX[!is_good_prefix])),
+        enumerate(unique(queries$PREFIX[!is_good_prefix])),
         "."
       )
     )
   }
 
   # check illegal prefix number
-  query_num <- sub("[[:alpha:]]+", "", queries$VAR_PREFIX)
+  query_num <- sub("[[:alpha:]]+", "", queries$PREFIX)
   is_bad_num <- nchar(query_num) != 2 | is.na(as.numeric(query_num))
   if (any(is_bad_num)) {
     abort(
       paste0(
-        "`VAR_PREFIX` in `", queries_name,
+        "`PREFIX` in `", queries_name,
         "` must end with 2-digit numbers. Issue with ",
-        enumerate(unique(queries$VAR_PREFIX[is_bad_num])),
+        enumerate(unique(queries$PREFIX[is_bad_num])),
         "."
       )
     )
   }
 
   # check illegal query name
-  if (any(queries$QUERY_NAME == "") | any(is.na(queries$QUERY_NAME))) {
+  if (any(queries$GRPNAME == "") || any(is.na(queries$GRPNAME))) {
     abort(paste0(
-      "`QUERY_NAME` in `", queries_name,
+      "`GRPNAME` in `", queries_name,
       "` cannot be empty string or NA."
     ))
   }
 
   # check query id is numeric
-  if ("QUERY_ID" %in% names(queries) && !is.numeric(queries$QUERY_ID)) {
+  if ("GRPID" %in% names(queries) && !is.numeric(queries$GRPID)) {
     abort(paste0(
-      "`QUERY_ID` in `", queries_name,
+      "`GRPID` in `", queries_name,
       "` should be numeric."
     ))
   }
 
   # check illegal query scope
-  if ("QUERY_SCOPE" %in% names(queries) &&
-    any(unique(queries$QUERY_SCOPE) %notin% c("BROAD", "NARROW", "", NA_character_))) {
+  if ("SCOPE" %in% names(queries) &&
+    any(unique(queries$SCOPE) %notin% c("BROAD", "NARROW", "", NA_character_))) {
     abort(paste0(
-      "`QUERY_SCOPE` in `", queries_name,
+      "`SCOPE` in `", queries_name,
       "` can only be 'BROAD', 'NARROW' or `NA`."
     ))
   }
 
   # check illegal query scope number
-  if ("QUERY_SCOPE_NUM" %in% names(queries)) {
-    is_bad_scope_num <- queries$QUERY_SCOPE_NUM %notin% c(1, 2, NA_integer_)
+  if ("SCOPEN" %in% names(queries)) {
+    is_bad_scope_num <- queries$SCOPEN %notin% c(1, 2, NA_integer_)
     if (any(is_bad_scope_num)) {
       abort(
         paste0(
-          "`QUERY_SCOPE_NUM` in `", queries_name,
+          "`SCOPEN` in `", queries_name,
           "` must be one of 1, 2, or NA. Issue with ",
-          enumerate(unique(queries$QUERY_SCOPE_NUM[is_bad_scope_num])),
+          enumerate(unique(queries$SCOPEN[is_bad_scope_num])),
           "."
         )
       )
@@ -294,22 +294,22 @@ assert_valid_queries <- function(queries, queries_name) {
   }
 
   # check illegal term name
-  if (any(is.na(queries$TERM_NAME) & is.na(queries$TERM_ID)) |
-    any(queries$TERM_NAME == "" & is.na(queries$TERM_ID))) {
+  if (any(is.na(queries$TERMNAME) & is.na(queries$TERMID)) ||
+    any(queries$TERMNAME == "" & is.na(queries$TERMID))) {
     abort(paste0(
-      "Either `TERM_NAME` or `TERM_ID` need to be specified",
+      "Either `TERMNAME` or `TERMID` need to be specified",
       " in `", queries_name, "`. ",
       "They both cannot be NA or empty."
     ))
   }
 
-  # each VAR_PREFIX must have unique QUERY_NAME, QUERY_ID if the columns exist
+  # each PREFIX must have unique GRPNAME, GRPID if the columns exist
   count_unique <- queries %>%
-    group_by(VAR_PREFIX) %>%
-    dplyr::summarise(
-      n_qnam = length(unique(QUERY_NAME)),
-      n_qid = ifelse("QUERY_ID" %in% names(queries),
-        length(unique(QUERY_ID)), 0
+    group_by(PREFIX) %>%
+    summarise(
+      n_qnam = length(unique(GRPNAME)),
+      n_qid = ifelse("GRPID" %in% names(queries),
+        length(unique(GRPID)), 0
       )
     ) %>%
     ungroup()
@@ -317,8 +317,8 @@ assert_valid_queries <- function(queries, queries_name) {
   if (any(count_unique$n_qnam > 1)) {
     idx <- which(count_unique$n_qnam > 1)
     abort(paste0(
-      "In `", queries_name, "`, `QUERY_NAME` of '",
-      paste(count_unique$VAR_PREFIX[idx], collapse = ", "),
+      "In `", queries_name, "`, `GRPNAME` of '",
+      paste(count_unique$PREFIX[idx], collapse = ", "),
       "' is not unique."
     ))
   }
@@ -326,14 +326,14 @@ assert_valid_queries <- function(queries, queries_name) {
   if (any(count_unique$n_qid > 1)) {
     idx <- which(count_unique$n_qid > 1)
     abort(paste0(
-      "In `", queries_name, "`, `QUERY_ID` of '",
-      paste(count_unique$VAR_PREFIX[idx], collapse = ", "),
+      "In `", queries_name, "`, `GRPID` of '",
+      paste(count_unique$PREFIX[idx], collapse = ", "),
       "' is not unique."
     ))
   }
 
-  # check QUERY_SCOPE and QUERY_SCOPE_NUM are one to one if available
-  if ("QUERY_SCOPE" %in% names(queries) & "QUERY_SCOPE_NUM" %in% names(queries)) {
-    assert_one_to_one(queries, exprs(QUERY_SCOPE), exprs(QUERY_SCOPE_NUM))
+  # check SCOPE and SCOPEN are one to one if available
+  if ("SCOPE" %in% names(queries) && "SCOPEN" %in% names(queries)) {
+    assert_one_to_one(queries, exprs(SCOPE), exprs(SCOPEN))
   }
 }
